#! /usr/bin/env Rscript

set.seed(27)

# generate synthetic classification data, with 3, 4 or 6 clusters
source("util.R")

# 3, 4 or 6 clusters
n.clust <- 6
# add.noise only works for 6 cluster problem which has 3 classes
add.noise <- TRUE 

if (n.clust == 3)
{
    train <- triClust()
    file.name <- "tri_clust.pdf"
} else if(n.clust == 4)
{
    train <- quadClust()
    file.name <- "quad_clust.pdf"
} else if (n.clust == 6)
{
    train <- hexClust(add.noise=add.noise)
    if (add.noise)
        file.name <- "hex_clust_cand.pdf"
    else
        file.name <- "hex_clust.pdf"
} else
    stop("Can only run demo with 3, 4 or 6 clusters")


X <- train$X
Y <- train$Y
label <- train$label


# instances with distractor labels will use gray color
color.index <- label
color.index[rowSums(Y) > 1] <- max(label) + 1

require("LSB.CMM")
alpha <- 0.05
K <- 10 
sigma2 <- 1 

model <- lsbcmm.fit(X=X, Y=Y, sigma2=sigma2, K=K, alpha=alpha)
prob <- predict(model, X)
acc <- sum(max.col(prob) == label) / nrow(Y)

print(paste("Accuracy on training data is ", acc))

#plot the data and the decision boundary
pdf(file.name)

par(family="Times")
pchs <- c(1, 2, 3)
colors <- c("blue", 'yellow4', "red", "gray")

plot(X[, 1], X[, 2], 
     main = "", xaxt = "n", yaxt = "n",
     xlab = "", ylab = "",
     pch = pchs[label], col=colors[color.index], 
     xlim=c(-1.7, 1.8), ylim=c(-1.7, 1.6))

axis(2, at=c(-1.6, -0.8, 0, 0.8, 1.6), labels=c(-1.6, -0.8, 0, 0.8, 1.6), las=0, cex=1.5)
axis(1, at=c(-1.6, -0.8, 0, 0.8, 1.6), labels=c(-1.6, -0.8, 0, 0.8, 1.6), las=0, cex=1.5)

legend("bottomright", inset=0.005, legend = paste("class", 1:ncol(Y)), pch=pchs, col=colors, cex=1.5)

drawBoundary(model, xlim=c(-1.8, 2.0), ylim=c(-1.8, 1.7))
dev.off()
