\name{lsbcmm.fit}
\alias{lsbcmm.fit}
\title{LSB-CMM Training}
\description{Fit an LSB-CMM model}
\usage{
lsbcmm.fit(X, Y, sigma2 = 1, K = (5 * ncol(Y)), alpha = 0.05, marg.theta = TRUE, quiet = FALSE)
}
\arguments{
\item{X}{fitting covariates, with each row as an instance}
\item{Y}{target indicator matrix. Each row is a vector of binary indicators 
for the corresponding instance in \code{X}. 
The indicated labels are a superset of the true label.}
\item{sigma2}{variance of the prior Gaussian distribution for weight vectors, playing the role of C}
\item{K}{the largest possible number of components}
\item{alpha}{parameter of the Dirichlet distribution, which is the prior of multinomial distribution. 
It has the length of $1$ or $K$. If it has length $1$, then it is used by each component.}
\item{marg.theta}{whether to marginalize $theta$ in optimization}
\item{quiet}{whether print messages. If not set, it will print the progress of lower bound. NOTE: the lower bound does not necessarily increasing with the setting \code{alpha < 1} and \code{marg.theta = FALSE} }
}
\details{

This function fit an LSB-CMM model. In this model, the probability of an instance to be in 
a mixture component is given by the stick-breaking process with discriminative function 
on  covariates. In the coding part, each mixture component is assigned a label from a 
multinomial distribution. The two parts are optimized simultaneously with the varitional
EM algorithm. 

}

\value{
a trained conditional mixture model with class \code{LSBCMM}.
}

\references{
\url{http://web.engr.oregonstate.edu/~liuli/}
}

\author{Li-Ping Liu \email{liuli@eecs.oregonstate.edu}}

\seealso{
\code{\link{predict.LSBCMM}}
}

\examples{
# A least squares regression example
# create some data
}

\keyword{superset}
\keyword{conditional}
\keyword{model}
