#include "util.h"

extern "C" {

#include <R.h>
#include <Rinternals.h>

SEXP DecompE(SEXP rdAlpha, SEXP radLogLprob, SEXP radElog, SEXP rLabel, SEXP rcK, SEXP rcL)
{
    double* logLprob = REAL(radLogLprob);
    double* eLog = REAL(radElog); 
    double alpha = REAL(rdAlpha)[0];

    int K = INTEGER(rcK)[0];
    int L = INTEGER(rcL)[0];
    int N = LENGTH(rLabel);
   
    SEXP rAns = NULL;
    PROTECT(rAns = allocVector(VECSXP, 4));
    SEXP radEalpha = NULL;  
    PROTECT(radEalpha = allocVector(REALSXP, K * L));
    SET_VECTOR_ELT(rAns,0,radEalpha);
    UNPROTECT(1);

    SEXP radEphi = NULL;  
    PROTECT(radEphi = allocVector(REALSXP, K * N));
    SET_VECTOR_ELT(rAns,1,radEphi);
    UNPROTECT(1);

    SEXP rdEnt = NULL;  
    PROTECT(rdEnt = allocVector(REALSXP, 1));
    SET_VECTOR_ELT(rAns,2,rdEnt);
    UNPROTECT(1);

    SEXP rdTerm3 = NULL;  
    PROTECT(rdTerm3 = allocVector(REALSXP, 1));
    SET_VECTOR_ELT(rAns,3,rdTerm3);
    UNPROTECT(1);

    UNPROTECT(1);

    double *ealpha = REAL(radEalpha);
    memset(ealpha, 0, sizeof(double) * K * L);

    double *ephi = REAL(radEphi);
    memset(ephi, 0, sizeof(double) * N * K);

    double& entropy = *(REAL(rdEnt));
    entropy = 0.0;

    double& term3 = *(REAL(rdTerm3));
    term3 = 0.0;

    int *fullLabel = new int[L];
    for (int i = 0; i < L; i++)
    {
        fullLabel[i] = i + 1;
    }
    double* insEphi = new double[K * L];
    
    for (int n = 0; n < N; n++)
    {
        SEXP rY = VECTOR_ELT(rLabel, n);
        int *insLab = NULL; 
        int nLab = 0;
        if (INTEGER(rY)[0] == -1)
        {
            insLab = fullLabel;
            nLab = L;
        } else
        {
            insLab = INTEGER(rY);
            nLab = LENGTH(rY);
        }

        for (int c = 0; c < nLab; c++)
        {
            int lab = insLab[c] - 1;
            for (int k = 0; k < K; k++)  
            {
                insEphi[c * K + k] = logLprob[n * K + k]  + eLog[lab * K + k];
            }
        }
        logNormalize(insEphi, nLab * K);

        //ephi has been initialized at the beginning
        for (int c = 0; c < nLab; c++)
        {
            int lab = insLab[c] - 1;


            for (int k = 0; k < K; k++)  
            {
                ephi[n * K + k] += insEphi[c * K + k];
                ealpha[lab * K + k] += insEphi[c * K + k];

                if (insEphi[c * K + k] > 0)
                {
                    entropy -= insEphi[c * K + k] * log(insEphi[c * K + k]);
                    term3 += insEphi[c * K + k] * eLog[lab * K + k];
                }
            }
        }

    }

    delete fullLabel; 
    delete insEphi;

    return rAns;
}
}
